package com.coob.sjts.api.stSjts;

import com.alibaba.fastjson.JSONObject;
import com.coob.sjts.common.stUtil.*;
import com.coob.sjts.common.stUtil.config.StPtConfig;
import com.coob.sjts.common.stUtil.config.StSjtsConfig;
import com.coob.sjts.common.stUtil.dto.DataUploadDTO;
import com.coob.sjts.common.stUtil.dto.FileCtls;
import com.coob.sjts.modules.mis.domain.sjts.*;
import com.coob.sjts.modules.mis.service.sjts.*;
import com.fasterxml.jackson.databind.ObjectMapper;

import com.google.common.collect.Lists;
import org.apache.commons.io.FileUtils;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang3.StringUtils;

import org.apache.http.client.methods.HttpPost;
import org.dom4j.Document;
import org.dom4j.DocumentHelper;
import org.dom4j.Element;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.*;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Base64;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.atomic.AtomicLong;
import java.util.stream.Collectors;
import java.util.stream.Stream;


/**
 * 省厅数据文件推送
 */
@Service
public class StDataService {

    @Autowired
    StPtConfig stPtConfig;
    @Autowired
    private SjtsStWqbaService sjtsStWqBaService;
    @Autowired
    private SjtsStYsxkzService sjtsStYsxkzService;
    @Autowired
    private SjtsStXmxxService sjtsStXmxxService;
    @Autowired
    private SjtsStJgzhmxService sjtsStJgzhmxService;
    @Autowired
    private SjtsStFwwqbaService sjtsStFwwqbaService;


    List<String> fileData = Stream.of(StringUtils.split("WQBA,XMXX,YSXKZ,JGZHMX", ",")).collect(Collectors.toList());

    List<String> fileDataFw = Stream.of(StringUtils.split("FWWQBA", ",")).collect(Collectors.toList());


    /**
     * 推送省厅数据  项目  预售证  监管账户  网签备案
     *
     * @throws Exception
     */
    public void sendData() throws Exception {
        String url = stPtConfig.getServerUrl() + "/auth/data/upload";
        //循环需要推送的文件
        for (String fileDatum : fileData) {
            // 请求地址，域名的需要替换生产环境的地址
            StringBuilder stringBuilder = new StringBuilder();
            // 当前时间
            String yyyyMMddHHmmss = LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyyMMddHHmmss"));
            // 请求序列号 发送交易流水号 规则，全局唯一，规则：接入应用编号+yyyyMMddHHmmss+4位顺序号
            String sendSeqNo = stPtConfig.getSendNode() + yyyyMMddHHmmss + getNumber(yyyyMMddHHmmss);
            String batchNo = getBatchNumber();// 批次号

            // 创建临时目录
            File tempDir = Files.createTempDirectory("tempDir").toFile();
            // 构建上报数据
            stringBuilder.append(fileDatum + ":");
            // 1.1 创建临时目录
            String dataName = fileDatum + ".dat";
            List data = null;
            switch (fileDatum) {
                case "WQBA":
                    data = sjtsStWqBaService.selectListByWTs();
                    break;
                case "XMXX":
                    data = sjtsStXmxxService.selectListByWts();
                    break;
                case "YSXKZ":
                    data = sjtsStYsxkzService.selectListByWts();
                    break;
                case "JGZHMX":
                    data = sjtsStJgzhmxService.selectListByWts();
                    break;
                default:
            }

            System.out.println(fileDatum + "数据加载完毕");

            String sjtsFileData = null;
            BufferedWriter bufferedWriter = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(new File(tempDir.getPath() + File.separator + dataName)), "utf-8"));
            int pcint = 0;
            for (Object obj : data) {
                switch (fileDatum) {
                    case "WQBA":
                        obj = (SjtsStWqba) obj;
                        break;
                    case "XMXX":
                        obj = (SjtsStXmxx) obj;
                        break;
                    case "YSXKZ":
                        obj = (SjtsStYsxkz) obj;
                        break;
                    case "JGZHMX":
                        obj = (SjtsStJgzhmx) obj;
                        break;
                    default:
                }
                sjtsFileData = lineData(obj);
                bufferedWriter.write(sjtsFileData);
                bufferedWriter.newLine();

                pcint = pcint + 1;
                obj = null;
                if (data.size() == pcint || pcint % 10000 == 0) {
                    //假定1万条数据压缩后是1M 通过1万条来分发

                    //强制将缓冲区的内容全部写入到输出流中，但不关闭流
                    bufferedWriter.flush();

                    //关闭输入/输出流
                    IOUtils.closeQuietly(bufferedWriter);
                    // todo 文件比较大时，需分批传送，传输的总批数,当前文件较小就1个批次,当前数量较小就只有1个批次
                    Integer batchNum = data.size() / 10000 + (data.size() % 10000 == 0 ? 0 : 1);
                    // 当前传输的批次号从1开始至batchNum
                    Integer currBatchNum = pcint / 10000 + (pcint % 10000 == 0 ? 0 : 1);

                    // 文件名； SendSeqNo_batchNo_batchNum_currBatchNum.zip
                    String fileName = sendSeqNo + "_" + batchNo + "_" + batchNum + "_" + currBatchNum + ".zip";

                    InputStream resourceAsStream = new FileInputStream(new File(tempDir.getPath() + File.separator + dataName));


                    // 1.3 构建校验文件
                    byte[] dataBytes = IOUtils.toByteArray(resourceAsStream);
                    FileUtils.writeByteArrayToFile(new File(tempDir.getPath() + File.separator + dataName), dataBytes);
                    byte[] hash = SM3Utils.hash(dataBytes);
                    String sign = HexUtil.byteToHex(hash);
                    String fileNameCtl = fileDatum + ".ctl";
                    FileCtls.FileCtl fileCtl = new FileCtls.FileCtl();
                    fileCtl.setFilename(dataName);
                    fileCtl.setRecordnum(countLinesInFile(dataBytes) + "");
                    fileCtl.setSignature(sign);
                    fileCtl.setEncoding("UTF-8");
                    String ctlString = getCtlString(fileCtl);
                    FileUtils.writeByteArrayToFile(new File(tempDir.getPath() + File.separator + fileNameCtl), ctlString.getBytes(StandardCharsets.UTF_8));
                    // 1.4 压缩文件

                    File zipFile = new File(tempDir.getParent() + File.separator + fileName);
                    OutputStream outputStream = null;

                    try {
                        ZipUtils.toZip(tempDir.getPath(), outputStream = new FileOutputStream(zipFile), true);
                    } finally {
                        IOUtils.closeQuietly(outputStream);
                    }
                    byte[] bytes1 = FileUtils.readFileToByteArray(zipFile);
                    // 删除临时文件及zip文件
                    tempDir.delete();
                    zipFile.delete();
                    // 1.5 base64编码
                    String base64Data = Base64.getEncoder().encodeToString(bytes1);
                    //通过签到密钥获取会话密钥
                    byte[] sessionKey = generateSignKey();

                    //示例参数
                    DataUploadDTO dataUploadDTO = new DataUploadDTO();
                    dataUploadDTO.setBatchNo(batchNo);
                    dataUploadDTO.setBatchNum(batchNum);
                    dataUploadDTO.setCurrBatchNum(currBatchNum);
                    DataUploadDTO.FileData fileData1 = new DataUploadDTO.FileData();
                    fileData1.setFileName(fileName);
                    fileData1.setFileData(base64Data);
                    dataUploadDTO.setFileList(fileData1);

                    // 构建发送数据
                    String siginBefore = StSjtsConfig.mapper.writeValueAsString(dataUploadDTO);
                    // 传输数据加签
                    String signWithSm2 = Sm2Util.sign(siginBefore, stPtConfig.getPrivateKey());

                    // 加密传输数据
                    byte[] bytes = Sm4Util.encode(sessionKey, siginBefore.getBytes(StandardCharsets.UTF_8));
                    // base64编码传输数据
                    String s1 = Base64.getEncoder().encodeToString(bytes);
                    HttpPost httpPost = new HttpPost(url);
                    Map<String, String> header = new HashMap<>();
                    // 应用凭证
                    header.put("SendNode", stPtConfig.getSendNode());
                    header.put("ReceiveNode", stPtConfig.getReceiveNode());
                    // 签名
                    header.put("Signature", signWithSm2);
                    // 传输的类型
                    header.put("Content-Type", "application/text");
                    header.put("TxCode", "FDC702");
                    // 交易机构编号,查看附件表
                    header.put("TxUnitNo", stPtConfig.getTxUnitNo());
                    header.put("SendSeqNo", sendSeqNo);
                    header.put("OperNo", "System");
                    header.put("CustNo", "FC01");
                    header.put("SendDate", LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyyMMdd")));
                    header.put("SendTime", LocalDateTime.now().format(DateTimeFormatter.ofPattern("HHmmss")));
                    System.out.println("702业务上传接口====" + header.toString());
                    String s = StHttpUtil.sendHttp(httpPost, header, s1);
                    JSONObject json = JSONObject.parseObject(s);
                    String o = (String) json.get("fileStatus");
                    if ("00000".equals(o)) {
                        if ("XMXX".equals(fileDatum)) {
                            sjtsStXmxxService.uppdateTsztOrTssj();
                            System.out.println("省厅项目信息推送完成");
                        } else if ("YSXKZ".equals(fileDatum)) {
                            sjtsStYsxkzService.uppdateTsztOrTssj();
                            System.out.println("省厅预售许可推送完成");
                        } else if ("JGZHMX".equals(fileDatum)) {
                            sjtsStJgzhmxService.uppdateTszt();
                            System.out.println("省厅监管账户推送完成");
                        } else {
                            sjtsStWqBaService.uppdateTsztOrTssj();
                            System.out.println("省厅网签备案推送完成");
                        }
                    }
                    stringBuilder.append(s);
                    System.out.println("702返回：" + stringBuilder.toString());

                    if (data.size() != pcint) {
                        bufferedWriter = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(new File(tempDir.getPath() + File.separator + dataName)), "utf-8"));
                    }
                }
            }
        }
    }

    /**
     * 推送房屋网签备案文件数据
     *
     * @throws Exception
     */
    public void sendDataFwWq() throws Exception {
        String url = stPtConfig.getServerUrl() + "/auth/data/upload";

        // 请求地址，域名的需要替换生产环境的地址
        StringBuilder stringBuilder = new StringBuilder();
        // 当前时间
        String yyyyMMddHHmmss = LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyyMMddHHmmss"));

        // 创建临时目录
        File tempDir = Files.createTempDirectory("tempDir").toFile();

        for (String fileDatum : fileDataFw) {
            // 构建上报数据
            stringBuilder.append(fileDatum + ":");
            // 1.1 创建临时目录
            String dataName = fileDatum + ".dat";
            //统计未推送信息数量
            int wtssl = sjtsStFwwqbaService.countFwBaByWts();
            List<SjtsStFwwqba> data = Lists.newArrayList();
            int pcint = 0;
            String FwaqSjbsLineData = null;
            int chaxuncount = 4000;        //查询条数
            int fenpi = 4000;              //批次推送数量  不能大于查询条数
            int zong = wtssl / chaxuncount + (wtssl % chaxuncount == 0 ? 0 : 1);
            int flag = 0;   //判断是否全部推送完成
            BufferedWriter bufferedWriter = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(new File(tempDir.getPath() + File.separator + dataName)), "utf-8"));

            for (int i = 0; i < zong; i++) {
                //查询需要推送的信息                         开始条数                    结束条数
                data = sjtsStFwwqbaService.selectListByFy(i * chaxuncount, (i + 1) * chaxuncount);
                for (SjtsStFwwqba datum : data) {
                    if (null != datum.getXmbs() && !datum.getXmbs().isEmpty() && null != datum.getXzqhdm() && !datum.getXzqhdm().isEmpty()) {
                        FwaqSjbsLineData = lineData(datum);
                        bufferedWriter.write(FwaqSjbsLineData);
                        bufferedWriter.newLine();
                    }
                    pcint = pcint + 1;
                    //wtssl == pcint 判断的是需要推送总数的最后一条   pcint % fenpi == 0 判断的是本批次推送的随后一条
                    if (wtssl == pcint || pcint % fenpi == 0) {

                        // 请求序列号 发送交易流水号 规则，全局唯一，规则：接入应用编号+yyyyMMddHHmmss+4位顺序号
                        String sendSeqNo = stPtConfig.getSendNode()+ yyyyMMddHHmmss + getNumber(yyyyMMddHHmmss);

                        String batchNo = getBatchNumber();// 批次号

                        bufferedWriter.flush();
                        IOUtils.closeQuietly(bufferedWriter);
                        // todo 文件比较大时，需分批传送，传输的总批数,当前文件较小就1个批次,当前数量较小就只有1个批次
                        Integer batchNum = wtssl / fenpi + (wtssl % fenpi == 0 ? 0 : 1);
                        // 当前传输的批次号从1开始至batchNum
                        Integer currBatchNum = pcint / fenpi + (pcint % fenpi == 0 ? 0 : 1);
                        // 文件名； SendSeqNo_batchNo_batchNum_currBatchNum.zip
                        String fileName = sendSeqNo + "_" + batchNo + "_" + batchNum + "_" + currBatchNum + ".zip";

                        InputStream resourceAsStream = new FileInputStream(new File(tempDir.getPath() + File.separator + dataName));
                        // 1.3 构建校验文件
                        byte[] dataBytes = IOUtils.toByteArray(resourceAsStream);

                        FileUtils.writeByteArrayToFile(new File(tempDir.getPath() + File.separator + dataName), dataBytes);
                        byte[] hash = SM3Utils.hash(dataBytes);
                        String sign = HexUtil.byteToHex(hash);
                        String fileNameCtl = fileDatum + ".ctl";
                        FileCtls.FileCtl fileCtl = new FileCtls.FileCtl();
                        fileCtl.setFilename(dataName);
                        fileCtl.setRecordnum(countLinesInFile(dataBytes) + "");
                        fileCtl.setSignature(sign);
                        fileCtl.setEncoding("UTF-8");
                        String ctlString = getCtlString(fileCtl);
                        FileUtils.writeByteArrayToFile(new File(tempDir.getPath() + File.separator + fileNameCtl), ctlString.getBytes(StandardCharsets.UTF_8));
                        // 1.4 压缩文件

                        File zipFile = new File(tempDir.getParent() + File.separator + fileName);
                        OutputStream outputStream = null;

                        try {
                            ZipUtils.toZip(tempDir.getPath(), outputStream = new FileOutputStream(zipFile), true);
                        } finally {
                            IOUtils.closeQuietly(outputStream);
                        }
                        byte[] bytes1 = FileUtils.readFileToByteArray(zipFile);
                        // 删除临时文件及zip文件
                        tempDir.delete();
                        zipFile.delete();

                        String base64Data = Base64.getEncoder().encodeToString(bytes1);
                        byte[] sessionKey = generateSignKey();
                        //示例参数
                        DataUploadDTO dataUploadDTO = new DataUploadDTO();
                        dataUploadDTO.setBatchNo(batchNo);
                        dataUploadDTO.setBatchNum(batchNum);
                        dataUploadDTO.setCurrBatchNum(currBatchNum);
                        DataUploadDTO.FileData fileData1 = new DataUploadDTO.FileData();
                        fileData1.setFileName(fileName);
                        fileData1.setFileData(base64Data);
                        dataUploadDTO.setFileList(fileData1);

                        // 构建发送数据
                        String siginBefore = StSjtsConfig.mapper.writeValueAsString(dataUploadDTO);
                        // 传输数据加签
                        String signWithSm2 = Sm2Util.sign(siginBefore, stPtConfig.getPrivateKey());

                        // 加密传输数据
                        byte[] bytes = Sm4Util.encode(sessionKey, siginBefore.getBytes(StandardCharsets.UTF_8));
                        // base64编码传输数据
                        String s1 = Base64.getEncoder().encodeToString(bytes);
                        HttpPost httpPost = new HttpPost(url);
                        Map<String, String> header = new HashMap<>();
                        // 应用凭证
                        header.put("SendNode", stPtConfig.getSendNode());
                        header.put("ReceiveNode", stPtConfig.getReceiveNode());
                        // 签名
                        header.put("Signature", signWithSm2);
                        // 传输的类型
                        header.put("Content-Type", "application/text");
                        header.put("TxCode", "FDC702");
                        // 交易机构编号,查看附件表
                        header.put("TxUnitNo", stPtConfig.getTxUnitNo());
                        header.put("SendSeqNo", sendSeqNo);
                        header.put("OperNo", "System");
                        header.put("CustNo", "FC01");
                        header.put("SendDate", LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyyMMdd")));
                        header.put("SendTime", LocalDateTime.now().format(DateTimeFormatter.ofPattern("HHmmss")));

                        System.out.println("702房屋网签备案上传接口====" + header.toString());
                        String s = StHttpUtil.sendHttp(httpPost, header, s1);

                        JSONObject json = JSONObject.parseObject(s);
                        String o = (String) json.get("fileStatus");
                        if ("00000".equals(o)) {
                            flag++;
                            System.out.println("房屋网签备案第" + flag + "批次上传成功");
                        }
                        System.out.println("702房屋网签备案返回：" + s);

                        bufferedWriter = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(new File(tempDir.getPath() + File.separator + dataName)), "utf-8"));
                    }
                }
            }
            System.out.println("房屋网签备案数据上传" + flag + "批次完成，总批次：" + zong);
            if (flag == zong) {
                sjtsStFwwqbaService.uppdateTsztOrTssj();
            }
        }
    }


    /* *
     * 获取签到密钥
     *
     * @return
     * @throws Exception
     */
    public byte[] generateSignKey() throws Exception {
        String path = "/auth/sign";
        ObjectMapper objectMapper = new ObjectMapper();
        //TxCode +  时间 + 应用id
        String yyyyMMdd = LocalDate.now().format(DateTimeFormatter.ofPattern("yyyyMMdd"));
        Map<String, Object> param = new HashMap<>();
        param.put("secKeyType", "F01");
        String paramString = objectMapper.writeValueAsString(param);
        String signWithSm2 = Sm2Util.sign(paramString, stPtConfig.getPrivateKey());
        HttpPost httpPost = new HttpPost(stPtConfig.getServerUrl() + path);
        Map<String, String> header = new HashMap<>();
        header.put("Signature", signWithSm2);
        header.put("SendNode", stPtConfig.getSendNode());
        header.put("ReceiveNode", stPtConfig.getReceiveNode());
        header.put("Content-Type", "application/text");
        header.put("TxCode", "FDC701");
        header.put("TxUnitNo", stPtConfig.getTxUnitNo());
        String yyyyMMddHHmmss = LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyyMMddHHmmss"));
        // 每次请求的序列化，不能相同
        String SendSeqNo = stPtConfig.getSendNode() + yyyyMMddHHmmss + getNumber(yyyyMMddHHmmss);
        // 发送序列化
        header.put("SendSeqNo", SendSeqNo);
        // 操作人员
        header.put("OperNo", "System");
        //渠道编号
        header.put("CustNo", "FC01");
        header.put("SendDate", LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyyMMdd")));
        header.put("SendTime", LocalDateTime.now().format(DateTimeFormatter.ofPattern("HHmmss")));
        // seesionkey， sm4加密后又base64加密进行传输
        String s = StHttpUtil.sendHttp(httpPost, header, paramString);
        System.out.println("获取会话结果"+s);

        Map map = objectMapper.readValue(s, Map.class);
        String sessionKey = (String) map.get("sessionKey");
        return Sm4Util.decode(("FCSP" + yyyyMMdd + stPtConfig.getCertificate()).getBytes(), Base64.getDecoder().decode(sessionKey));
    }


    /* *
     * 当前请求的序列号
     *
     * @param key 当前的日期
     * @return 返回补充0的四位序列化
     */
    public synchronized String getNumber(String key) {
        // todo 改代码用于演示，实际的顺序号按自己的业务来
        AtomicLong atomicLong = StSjtsConfig.atomicLongMap.get(key);
        if (atomicLong == null) {
            StSjtsConfig.atomicLongMap.put(key, atomicLong = new AtomicLong(0));
        }
        return StringUtils.leftPad(atomicLong.getAndIncrement() + "", 4, "0");
    }

    /**
     * 获取递增批次 8位日期（yyyyMMdd）+4位顺序号
     *
     * @return 返回
     */
    public String getBatchNumber() {
        String yyyyMMdd = LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyyMMdd"));
        String number = getNumber(yyyyMMdd);
        // 12位数据
        return yyyyMMdd + number;
    }

    /**
     * 定义一个方法，接受一个文件路径作为参数，返回该文件的行数
     */
    public static int countLinesInFile(byte[] filePath) throws IOException {
        // 创建一个BufferedReader对象，用来读取文件
        ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream(filePath);
        BufferedReader br = new BufferedReader(new InputStreamReader(byteArrayInputStream));
        // 创建一个计数器变量，初始化为0
        int count = 0;
        // 使用一个循环，每次读取一行数据，直到文件结束
        while (br.readLine() != null) {
            // 每次读取一行数据就加一
            count++;
        }
        // 关闭BufferedReader对象
        br.close();
        // 返回计数器变量的值
        return count;
    }


    private String getCtlString(FileCtls.FileCtl fileCtl) throws IOException {
        Document document = DocumentHelper.createDocument();
        document.setXMLEncoding("UTF-8");
        Element root = document.addElement("transmit-content");
        Element file = root.addElement("file");
        Element filename = file.addElement("filename");
        filename.setText(fileCtl.getFilename());
        Element recordnum = file.addElement("recordnum");
        recordnum.setText(fileCtl.getRecordnum());
        Element signature = file.addElement("signature");
        signature.setText(fileCtl.getSignature());
        Element encoding = file.addElement("encoding");
        encoding.setText("utf8");

        StringWriter stringWriter = new StringWriter();
        document.write(stringWriter);
        return stringWriter.toString();
    }

    /**
     * 拼接文件内容
     *
     * @param obj
     * @return
     */
    private static String lineData(Object obj) {
        String splitChar = "|@|";
        if (obj.getClass().getTypeName().contains("SjtsStYsxkz")) {
            SjtsStYsxkz acc = (SjtsStYsxkz) obj;
            return acc.getXmbs() + splitChar
                    + acc.getXh() + splitChar
                    + acc.getYsxkzbm() + splitChar
                    + acc.getYsxkzh() + splitChar
                    + acc.getXmmc() + splitChar
                    + acc.getXmbh() + splitChar
                    + acc.getYslds() + splitChar
                    + acc.getYsts() + splitChar
                    + acc.getYsmj() + splitChar
                    + acc.getYszzts() + splitChar
                    + acc.getYszzmj() + splitChar
                    + acc.getYssymj() + splitChar
                    + acc.getYsqtmj() + splitChar
                    + acc.getGcjdjdbm() + splitChar
                    + acc.getGcjdjdmc() + splitChar
                    + acc.getWcjfsxhxzj() + splitChar
                    + acc.getSsjt() + splitChar
                    + acc.getKfqymc() + splitChar
                    + acc.getKfqytyshxydm() + splitChar
                    + acc.getFzsj() + splitChar
                    + acc.getZskssj() + splitChar
                    + acc.getZsjssj() + splitChar
                    + acc.getXzqhmc() + splitChar
                    + acc.getXzqhdm() + splitChar
                    + acc.getCityname() + splitChar
                    + acc.getCityno() + splitChar
                    + acc.getSjscsj() + splitChar
                    + acc.getSjgxsj();
        } else if (obj.getClass().getTypeName().contains("SjtsStXmxx")) {
            SjtsStXmxx acc = (SjtsStXmxx) obj;
            return acc.getXh() + splitChar
                    + acc.getXmbs() + splitChar
                    + acc.getXmmc() + splitChar
                    + acc.getXmbh() + splitChar
                    + acc.getXmxz() + splitChar
                    + acc.getJfbz() + splitChar
                    + acc.getXmrzfl() + splitChar
                    + acc.getKfqy() + splitChar
                    + acc.getFqsx() + splitChar
                    + acc.getXmssjtgs() + splitChar
                    + acc.getKfqytyshxydm() + splitChar
                    + acc.getQyssjtsdhf() + splitChar
                    + acc.getKfqyzzdj() + splitChar
                    + acc.getKcdw() + splitChar
                    + acc.getKcdwtyshxydm() + splitChar
                    + acc.getSjdw() + splitChar
                    + acc.getSjdwyshxydm() + splitChar
                    + acc.getSgdw() + splitChar
                    + acc.getSgdwtyshxydm() + splitChar
                    + acc.getJldw() + splitChar
                    + acc.getJldwtyshxydm() + splitChar
                    + acc.getXmjhztz() + splitChar
                    + acc.getLjywctz() + splitChar
                    + acc.getDnjhtze() + splitChar
                    + acc.getDnljywctze() + splitChar
                    + acc.getBndzj() + splitChar
                    + acc.getBndzjly() + splitChar
                    + acc.getZdmj() + splitChar
                    + acc.getGhjzmj() + splitChar
                    + acc.getGhzjjzmj() + splitChar
                    + acc.getGhzts() + splitChar
                    + acc.getGhzzzts() + splitChar
                    + acc.getKgrq() + splitChar
                    + acc.getJhjgrq() + splitChar
                    + acc.getJsydghxkz() + splitChar
                    + acc.getTdsyz() + splitChar
                    + acc.getJzgcghxkz() + splitChar
                    + acc.getJsgcsgxkz() + splitChar
                    + acc.getXxjd() + splitChar
                    + acc.getXzqhdm() + splitChar
                    + acc.getCityno() + splitChar
                    + acc.getXmsz() + splitChar
                    + acc.getJd() + splitChar
                    + acc.getWd() + splitChar
                    + acc.getXmdz() + splitChar
                    + acc.getSjscsj() + splitChar
                    + acc.getSjgxsj();
        } else if (obj.getClass().getTypeName().contains("SjtsStWqba")) {
            SjtsStWqba wqba = (SjtsStWqba) obj;
            return wqba.getXmbs() + splitChar
                    + wqba.getWqlx() + splitChar
                    + wqba.getWqbazzje() + splitChar
                    + wqba.getWqbasyje() + splitChar
                    + wqba.getBnwqbats() + splitChar
                    + wqba.getBnwqbamj() + splitChar
                    + wqba.getBnwqbaje() + splitChar
                    + wqba.getBnwqbazzts() + splitChar
                    + wqba.getBnwqbazzmj() + splitChar
                    + wqba.getBnwqbazzje() + splitChar
                    + wqba.getBnwqbasyts() + splitChar
                    + wqba.getBnwqbasymj() + splitChar
                    + wqba.getBnwqbasyje() + splitChar
                    + wqba.getXh() + splitChar
                    + wqba.getYsxkzbm() + splitChar
                    + wqba.getYsxkzh() + splitChar
                    + wqba.getXmmc() + splitChar
                    + wqba.getXmbh() + splitChar
                    + wqba.getWqbats() + splitChar
                    + wqba.getWqbamj() + splitChar
                    + wqba.getWqbazzts() + splitChar
                    + wqba.getWqbazzmj() + splitChar
                    + wqba.getWqbasymj() + splitChar
                    + wqba.getWqbaqtmj() + splitChar
                    + wqba.getHtydjfrq() + splitChar
                    + wqba.getJbjftjrq() + splitChar
                    + wqba.getSjscjfrq() + splitChar
                    + wqba.getLjysjfts() + splitChar
                    + wqba.getLjysjfmj() + splitChar
                    + wqba.getXzqhmc() + splitChar
                    + wqba.getXzqhdm() + splitChar
                    + wqba.getCityname() + splitChar
                    + wqba.getCityno() + splitChar
                    + wqba.getSjscsj() + splitChar
                    + wqba.getSjgxsj();
        } else if (obj.getClass().getTypeName().contains("SjtsStJgzhmx")) {
            SjtsStJgzhmx acc = (SjtsStJgzhmx) obj;
            return acc.getXmbs() + splitChar
                    + acc.getJgbz() + splitChar
                    + acc.getYlcbl() + splitChar
                    + acc.getXh() + splitChar
                    + acc.getXmmc() + splitChar
                    + acc.getXmbh() + splitChar
                    + acc.getJgyhdm() + splitChar
                    + acc.getJgyhmc() + splitChar
                    + acc.getJgzh() + splitChar
                    + acc.getJgxybh() + splitChar
                    + acc.getJgxyed() + splitChar
                    + acc.getJgzhye() + splitChar
                    + acc.getXzqhmc() + splitChar
                    + acc.getXzqhdm() + splitChar
                    + acc.getCityname() + splitChar
                    + acc.getCityno() + splitChar
                    + acc.getSjscsj() + splitChar
                    + acc.getSjgxsj();
        } else if (obj.getClass().getTypeName().contains("SjtsStFwwqba")) {
            SjtsStFwwqba acc = (SjtsStFwwqba) obj;
            return acc.getXmbs() + splitChar
                    + acc.getZcs() + splitChar
                    + acc.getCg() + splitChar
                    + acc.getDscs() + splitChar
                    + acc.getDxcs() + splitChar
                    + acc.getJgysbarq() + splitChar
                    + acc.getPgjg() + splitChar
                    + acc.getSfyd() + splitChar
                    + acc.getHtzyjjfs() + splitChar
                    + acc.getFkfs() + splitChar
                    + acc.getQlxz() + splitChar
                    + acc.getSjscsj() + splitChar
                    + acc.getSjgxsj() + splitChar
                    + acc.getXh() + splitChar
                    + acc.getYwbh() + splitChar
                    + acc.getLlywlb() + splitChar
                    + acc.getLlywlbbm() + splitChar
                    + acc.getSjywlb() + splitChar
                    + acc.getYywbh() + splitChar
                    + acc.getJyzt() + splitChar
                    + acc.getJyywzmzsmc() + splitChar
                    + acc.getJyywzmzsmcbm() + splitChar
                    + acc.getJyywzmzsh() + splitChar
                    + acc.getDjywzmzsmc() + splitChar
                    + acc.getDjywzmzsmcbm() + splitChar
                    + acc.getDjywzmzsh() + splitChar
                    + acc.getJyzlb() + splitChar
                    + acc.getJyzlbbm() + splitChar
                    + acc.getJyzqc() + splitChar
                    + acc.getJyzzjmc() + splitChar
                    + acc.getJyzzjmcbm() + splitChar
                    + acc.getJyzzjhm() + splitChar
                    + acc.getJyzxz() + splitChar
                    + acc.getJyzxzbm() + splitChar
                    + acc.getJyzhj() + splitChar
                    + acc.getJyzhjxzqh() + splitChar
                    + acc.getBdcdyh() + splitChar
                    + acc.getFwbm() + splitChar
                    + acc.getFwzt() + splitChar
                    + acc.getXzqhdm() + splitChar
                    + acc.getQx() + splitChar
                    + acc.getXzjdb() + splitChar
                    + acc.getJjxzqh() + splitChar
                    + acc.getJjxzqhdm() + splitChar
                    + acc.getLjx() + splitChar
                    + acc.getXq() + splitChar
                    + acc.getLh() + splitChar
                    + acc.getSzqsc() + splitChar
                    + acc.getSzzzc() + splitChar
                    + acc.getMyc() + splitChar
                    + acc.getDy() + splitChar
                    + acc.getFh() + splitChar
                    + acc.getFwzl() + splitChar
                    + acc.getHxjs() + splitChar
                    + acc.getHxjsbm() + splitChar
                    + acc.getHxjg() + splitChar
                    + acc.getHxjgbm() + splitChar
                    + acc.getFwcx() + splitChar
                    + acc.getFwcxbm() + splitChar
                    + acc.getJzmj() + splitChar
                    + acc.getTnjzmj() + splitChar
                    + acc.getGtjzmj() + splitChar
                    + acc.getGhyt() + splitChar
                    + acc.getJzjg() + splitChar
                    + acc.getJzjgbm() + splitChar
                    + acc.getFwyt() + splitChar
                    + acc.getFwytbm() + splitChar
                    + acc.getFwxz() + splitChar
                    + acc.getFwxzbm() + splitChar
                    + acc.getFwlx() + splitChar
                    + acc.getFwlxbm() + splitChar
                    + acc.getGyfs() + splitChar
                    + acc.getGyfsbm() + splitChar
                    + acc.getSzfe() + splitChar
                    + acc.getCjje() + splitChar
                    + acc.getFklx() + splitChar
                    + acc.getFklxbm() + splitChar
                    + acc.getDkfs() + splitChar
                    + acc.getDkfsbm() + splitChar
                    + acc.getHtsxrq() + splitChar
                    + acc.getYwbjsj() + splitChar
                    + acc.getYwbjrsfzh() + splitChar
                    + acc.getYwblszxzqhdm();
        }
        return "";
    }


}
