package com.coob.sjts.common.plugin;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import springfox.documentation.builders.ApiInfoBuilder;
import springfox.documentation.builders.ParameterBuilder;
import springfox.documentation.builders.PathSelectors;
import springfox.documentation.builders.RequestHandlerSelectors;
import springfox.documentation.schema.ModelRef;
import springfox.documentation.service.ApiInfo;
import springfox.documentation.service.Contact;
import springfox.documentation.service.Parameter;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spring.web.plugins.Docket;
import springfox.documentation.swagger2.annotations.EnableSwagger2WebMvc;

import java.util.ArrayList;
import java.util.List;

/**
 * @author : wangqingli
 * @Description: knife4j配置信息
 * <p>
 * 文档地址：https://doc.xiaominfo.com/
 * knife4j是为Java MVC框架集成Swagger生成Api文档的增强解决方案。
 * <p>
 * <p>
 * http://ip:port/doc.html  查看地址
 * <p>
 * @date 2024-06-01-17:27
 * @modify by：wangqingli
 */
@Configuration
@EnableSwagger2WebMvc
public class Knife4jConfig {
    @Bean
    public Docket adminApiConfig() {
        List<Parameter> pars = new ArrayList<>();
        //设置header里面的token
        ParameterBuilder tokenPar = new ParameterBuilder();
        tokenPar.name("token")
                .description("用户token")
                .defaultValue("")
                .modelRef(new ModelRef("string"))
                .parameterType("header")
                .required(false)
                .build();
        pars.add(tokenPar.build());
        //添加head参数end

        Docket adminApi = new Docket(DocumentationType.SWAGGER_2)
                .groupName("adminApi")
                // apiInfo()：配置 API 的一些基本信息，比如：文档标题title，文档描述description，文档版本号version
                .apiInfo(adminApiInfo())
                // select()：生成 API 文档的选择器，用于指定要生成哪些 API 文档
                .select()
                // apis()：指定要生成哪个包下的 API 文档
                .apis(RequestHandlerSelectors.basePackage("com.coob.sjts.modules"))
                // paths()：指定要生成哪个 URL 匹配模式下的 API 文档。这里使用 PathSelectors.any()，表示生成所有的 API 文档
                .paths(PathSelectors.any())
//                .paths(PathSelectors.regex("/sjts/.*"))
                .build()
                .globalOperationParameters(pars);
        return adminApi;
    }

    /**
     * /apiInfo()：配置 API 的一些基本信息，
     * 比如：文档标题title，文档描述description，文档版本号version
     *
     * @return
     */
    private ApiInfo adminApiInfo() {

        return new ApiInfoBuilder()
                .title("多数据源操作-API文档")
                .description("本文档描述了多数据源查询数据库数据")
                .version("1.0")
                .contact(new Contact("coob", "http://coob.com", "coob@qq.com"))
                .build();
    }

}
