package com.coob.sjts.common.stUtil;


import com.coob.sjts.common.stUtil.config.StSjtsConfig;
import org.apache.commons.collections.MapUtils;
import org.apache.commons.io.IOUtils;
import org.apache.http.HttpEntityEnclosingRequest;
import org.apache.http.NoHttpResponseException;
import org.apache.http.client.HttpRequestRetryHandler;
import org.apache.http.client.config.RequestConfig;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpRequestBase;
import org.apache.http.client.protocol.HttpClientContext;
import org.apache.http.config.Registry;
import org.apache.http.config.RegistryBuilder;
import org.apache.http.conn.ConnectTimeoutException;
import org.apache.http.conn.socket.ConnectionSocketFactory;
import org.apache.http.conn.socket.LayeredConnectionSocketFactory;
import org.apache.http.conn.socket.PlainConnectionSocketFactory;
import org.apache.http.conn.ssl.SSLConnectionSocketFactory;
import org.apache.http.entity.ByteArrayEntity;
import org.apache.http.entity.ContentType;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.impl.conn.PoolingHttpClientConnectionManager;
import org.apache.http.protocol.HttpContext;
import org.apache.http.util.EntityUtils;
import org.springframework.http.HttpStatus;

import javax.net.ssl.SSLException;
import javax.net.ssl.SSLHandshakeException;
import java.io.IOException;
import java.io.InputStream;
import java.io.InterruptedIOException;
import java.net.UnknownHostException;
import java.util.Map;

/**
 * @Author: rongb
 * @Date: 2023/09/04/14:30
 * @Description:
 */
public class StHttpUtil {



    private static PoolingHttpClientConnectionManager connMgr; //连接池
    private static HttpRequestRetryHandler retryHandler; //重试机制

    static {
        cfgPoolMgr();
        cfgRetryHandler();
    }


    /**
     * @return
     * @description 获取HttpClient
     */
    private static CloseableHttpClient getHttpClient() {
        return HttpClients.custom().setConnectionManager(connMgr).setRetryHandler(retryHandler).build();
    }

    public static String sendHttp(HttpRequestBase reqBase, Map<String, String> headers, Object param) throws Exception {
        long startTime = System.currentTimeMillis();
        CloseableHttpClient httpClient = getHttpClient();
        //设置请求url
        config(reqBase);

        //设置请求头
        if (MapUtils.isNotEmpty(headers)) {
            for (Map.Entry<String, String> entry : headers.entrySet()) {
                reqBase.setHeader(entry.getKey(), entry.getValue());
            }
        }

        //添加参数 参数是json字符串
        if (param != null && param instanceof String) {
            String paramStr = String.valueOf(param);

            ((HttpEntityEnclosingRequest) reqBase).setEntity(new StringEntity(String.valueOf(paramStr), ContentType.create("application/json", "UTF-8")));
        }
        //参数时字节流数组
        else if (param != null && param instanceof byte[]) {

            byte[] paramBytes = (byte[]) param;
            ((HttpEntityEnclosingRequest) reqBase).setEntity(new ByteArrayEntity(paramBytes));
        }


        //响应对象
        CloseableHttpResponse res = null;
        //响应内容
        String resCtx = null;
        try {
            //执行请求
            res = httpClient.execute(reqBase);
            if (res.getStatusLine().getStatusCode() != HttpStatus.OK.value()) {
                InputStream content = res.getEntity().getContent();
                String utf8 = IOUtils.toString(content, "utf8");
                System.out.println(utf8);
                throw new RuntimeException("--->>HTTP访问异常:" + res.getStatusLine());
            }

            //获取请求响应对象和响应entity
            org.apache.http.HttpEntity httpEntity = res.getEntity();
            if (httpEntity != null) {
                resCtx = EntityUtils.toString(httpEntity, "utf-8");
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException("请求失败", e);
        } finally {
            if (res != null) {
                try {
                    res.close();
                } catch (IOException e) {
                    throw new RuntimeException("--->>关闭请求响应失败", e);
                }
            }
        }
        long endTime = System.currentTimeMillis();

        return resCtx;
    }





    /**
     * @param httpReqBase
     * @description 请求头和超时时间配置
     */
    private static void config(HttpRequestBase httpReqBase) {
        // 配置请求的超时设置
        RequestConfig requestConfig = RequestConfig.custom().setConnectionRequestTimeout(StSjtsConfig.MAX_TIMEOUT).setConnectTimeout(StSjtsConfig.MAX_TIMEOUT).setSocketTimeout(StSjtsConfig.MAX_TIMEOUT).build();
        httpReqBase.setConfig(requestConfig);
    }




    /**
     * @return
     * @description 连接池配置
     */
    private static void cfgPoolMgr() {
        ConnectionSocketFactory plainsf = PlainConnectionSocketFactory.getSocketFactory();
        LayeredConnectionSocketFactory sslsf = SSLConnectionSocketFactory.getSocketFactory();

        Registry<ConnectionSocketFactory> registry = RegistryBuilder.<ConnectionSocketFactory>create().register("http", plainsf).register("https", sslsf).build();

        //连接池管理器
        connMgr = new PoolingHttpClientConnectionManager(registry);
        //最大连接数
        connMgr.setMaxTotal(StSjtsConfig.MAX_TOTAL);
        //每个路由基础的连接数
        connMgr.setDefaultMaxPerRoute(StSjtsConfig.ROUTE_MAX_TOTAL);
    }


    /**
     * @description 设置重试机制
     * @author 宫清
     * @date 2019年7月11日 上午1:06:24
     */
    private static void cfgRetryHandler() {
        retryHandler = new HttpRequestRetryHandler() {


            public boolean retryRequest(IOException e, int excCount, HttpContext ctx) {
                //超过最大重试次数，就放弃
                if (excCount > StSjtsConfig.MAX_RETRY) {
                    return false;
                }
                //服务器丢掉了链接，就重试
                if (e instanceof NoHttpResponseException) {
                    return true;
                }
                //不重试SSL握手异常
                if (e instanceof SSLHandshakeException) {
                    return false;
                }
                //中断
                if (e instanceof InterruptedIOException) {
                    return false;
                }
                //目标服务器不可达
                if (e instanceof UnknownHostException) {
                    return false;
                }
                //连接超时
                if (e instanceof ConnectTimeoutException) {
                    return false;
                }
                //SSL异g常
                if (e instanceof SSLException) {
                    return false;
                }

                HttpClientContext clientCtx = HttpClientContext.adapt(ctx);
                org.apache.http.HttpRequest req = clientCtx.getRequest();
                //如果是幂等请求，就再次尝试
                if (!(req instanceof HttpEntityEnclosingRequest)) {
                    return true;
                }
                return false;
            }
        };
    }

}
