package com.coob.sjts.modules.mis.mapper;


import com.coob.sjts.datasource.constant.DBConstants;
import com.coob.sjts.modules.mis.domain.sjts.SjtsZjbJglz;
import org.apache.ibatis.annotations.Mapper;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 监管楼幢表
 *  用于住建部数据推送
 */
@Mapper
@Transactional(transactionManager = DBConstants.TX_MANAGER_MIS)
public interface SjtsZjbJglzMapper {

    /**
     * 新增数据
     * @param lz
     * @return
     */
    int insert(SjtsZjbJglz lz);

    /**
     * 批量新增
     * @param list
     * @return
     */
    int insertBatch(List<SjtsZjbJglz> list);

    /**
     * 修改数据
     * @param lz
     * @return
     */
    int update(SjtsZjbJglz lz);

    int updateBatch(List<SjtsZjbJglz> list);

    /**
     * 查询监管楼幢中所有楼幢的发证状态。并将已经发证的楼幢的zt字段设置为2
     * @return
     */
    int updateZtByQzff();

    /**
     * 按项目更新是否签署过纸质合同（备案的）
     * @return
     */
    int updateZzht();

    /**
     * 按项目更新是否签署过电子合同
     * @return
     */
    int updateDzht();

    /**
     * 根据合同变更zt，签署过纸质合同、但未签署过电子合同的，认为是老项目
     * @return
     */
    int updateZtByHt();

    /**
     * 更新合同约定交付日期 - 按楼幢更新
     * 因为只有电子合同的 约定交付日期能够直接读取，所以该数据可能不全（没有纸质合同数据）
     * @return
     */
    int updateJfrqByLz();

    /**
     * 更新合同约定交付日期 - 按项目更新
     * 按项目查询不太精确，仅为了补充按楼幢查不到的情况
     * @return
     */
    int updateJfrqByXm();

    /**
     * 根据楼幢ID删除
     * @param lzid
     * @return
     */
    int deleteByLzid(String lzid);

    /**
     * 删除所有数据
     * @return
     */
    int deleteAll();

    /**
     * 根据状态查询列表
     * @param zt
     * @return
     */
    List<SjtsZjbJglz> selectListByZt(Integer zt);

    /**
     * 查询所有列表
     * @return
     */
    List<SjtsZjbJglz> selectListAll();

    /**
     * 查询在建的项目信息列表
     * @return
     */
    List<SjtsZjbJglz> selectXmxxList();

}
