package com.coob.sjts.modules.system.controller;

import com.coob.sjts.common.web.BaseController;
import com.coob.sjts.common.web.Result;
import com.coob.sjts.modules.system.domain.SysUser;
import com.coob.sjts.modules.system.service.SysMenuService;
import com.coob.sjts.modules.system.service.SysUserService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.servlet.ModelAndView;

import javax.annotation.Resource;

/**
 * @Author: Gao
 * @Date: 2024/1/30/17:41
 * @Description: 用户登录
 */
@RestController
public class LoginController extends BaseController {

    @Resource
    private SysMenuService menuService;
    @Resource
    private SysUserService sysUserService;

    /**
     * 登陆页面
     * @return
     */
    @GetMapping("login")
    public ModelAndView login(){
        return jumpPage("login");
    }
    /**
     * 登陆页面
     * @return
     */
    @PostMapping("login")
    public Result login( SysUser sysUser){
        String msg = sysUser.checkLogin();
        if(StringUtils.isNotBlank(msg)){
            return Result.failure(msg);
        }
        return Result.success("登陆成功");
    }


    /**
     * 主页
     * @return
     */
    @GetMapping("index")
    public ModelAndView index(){
        return jumpPage("index");
    }

    /**
     * 首页
     * @return
     */
    @GetMapping("console")
    public ModelAndView home() {
        return jumpPage("console/console");
    }

//    /**
//     * 菜单
//     * @return
//     */
//    @GetMapping("getMenuList")
//    public List<SysMenu> getMenuList(){
//        SysUser currentUser = this.getCurrentUser();
//        List<SysMenu> menus = menuService.selectMenusByRoleId(currentUser.getRoleId());
//        return menus;
//    }

    /**
     * Describe:无权限页面
     * Return:返回403页面
     */
    @GetMapping("error/403")
    public ModelAndView noPermission() {
        return jumpPage("error/403");
    }

    /**
     * Describe:找不带页面
     * Return:返回404页面
     */
    @GetMapping("error/404")
    public ModelAndView notFound() {
        return jumpPage("error/404");
    }

    /**
     * Describe:异常处理页
     * Return:返回500界面
     */
    @GetMapping("error/500")
    public ModelAndView onException() {
        return jumpPage("error/500");
    }

}
