package com.coob.sjts.modules.system.controller;

import com.coob.sjts.common.web.Result;
import com.coob.sjts.modules.system.domain.SysMenu;
import com.coob.sjts.modules.system.service.SysMenuService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * 菜单表(SysMenu)表控制层
 *
 * @author wangqingli
 * @since 2024-05-30 14:11:01
 */
@Api(tags = "系统菜单")
@RestController
@RequestMapping("sys/menu")
public class SysMenuController {
    /**
     * 服务对象
     */
    @Resource
    private SysMenuService sysMenuService;

    /**
     * 新增数据
     *
     * @param sysMenu 实体
     * @return 新增结果
     */
    @ApiOperation(value = "添加菜单")
    @PostMapping("/add")
    public Result add(@RequestBody SysMenu sysMenu) {
        String msg = sysMenu.checkAddParams();
        if (StringUtils.isNotBlank(msg)) {
            return Result.failure(msg);
        }
        sysMenu.setState(1);

        boolean insert = this.sysMenuService.insert(sysMenu);
        if (insert) {
            return Result.success();
        }
        return Result.failure();

    }

    /**
     * 删除数据
     *
     * @param id 主键
     * @return 删除是否成功
     */
    @ApiOperation(value = "删除菜单")
    @GetMapping("/deleteById/{id}")
    public Result deleteById(@PathVariable Long id) {
        if (id == null) {
            return Result.failure("id不能为空");
        }
        return Result.success(this.sysMenuService.deleteById(id));
    }

    /**
     * 编辑数据
     *
     * @param sysMenu 实体
     * @return 编辑结果
     */
    @ApiOperation(value = "编辑菜单")
    @PostMapping("/edit")
    public Result edit(@RequestBody SysMenu sysMenu) {
        String msg = sysMenu.checkEditParams();
        if (StringUtils.isNotBlank(msg)) {
            return Result.failure(msg);
        }
        boolean update = this.sysMenuService.update(sysMenu);
        if (update) {
            return Result.success();
        }
        return Result.failure();
    }


    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @ApiOperation(value = "通过主键查询单条数据")
    @GetMapping("/selectById/{id}")
    public Result selectById(@PathVariable("id") Long id) {
        if (id == null) {
            return Result.failure("id不能为空");
        }
        return Result.success(this.sysMenuService.selectById(id));
    }


    @ApiOperation("根据角色获取菜单 - 树形结构 - 本角色的被选中")
    @GetMapping("/selectAssign/{roleId}")
    public Result selectAssign(@PathVariable Long roleId) {
        if (roleId == null) {
            return Result.failure("角色id不能为空");
        }
        List<SysMenu> list = sysMenuService.selectMenuByRoleId(roleId);
        return Result.success(list);
    }

}

