package com.coob.sjts.modules.system.controller;

import com.coob.sjts.common.web.PageVo;
import com.coob.sjts.common.web.Result;
import com.coob.sjts.modules.system.domain.SysRole;
import com.coob.sjts.modules.system.service.SysRoleService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * 角色(SysRole)表控制层
 *
 * @author wangqingli
 * @since 2024-05-30 14:11:21
 */
@Api(tags = "角色菜单")
@RestController
@RequestMapping("sys/role")
public class SysRoleController {
    /**
     * 服务对象
     */
    @Resource
    private SysRoleService sysRoleService;

    /**
     * 新增数据
     *
     * @param sysRole 实体
     * @return 新增结果
     */
    @ApiOperation(value = "新增角色数据")
    @PostMapping("/add")
    public Result add(@RequestBody SysRole sysRole) {
        // 参数检查
        String msg = sysRole.checkAddParams();
        if (StringUtils.isNotBlank(msg)) {
            return Result.failure(msg);
        }
        sysRole.setState(1);

        if (StringUtils.isNotBlank(msg)) {
            return Result.failure(msg);
        }
        return Result.success(this.sysRoleService.insert(sysRole));
    }

    /**
     * 删除数据
     *
     * @param id 主键
     * @return 删除是否成功
     */
    @ApiOperation(value = "删除角色数据")
    @GetMapping("/deleteById/{id}")
    public Result deleteById(@PathVariable Long id) {
        if (id == null) {
            return Result.failure("id不能为空");
        }
        return Result.success(this.sysRoleService.deleteById(id));
    }


    /**
     * 编辑数据
     *
     * @param sysRole 实体
     * @return 编辑结果
     */
    @ApiOperation(value = "编辑角色数据")
    @PostMapping("/edit")
    public Result edit(@RequestBody SysRole sysRole) {
        String msg = sysRole.checkEditParams();
        if (StringUtils.isNotBlank(msg)) {
            return Result.failure(msg);
        }
        return Result.success(this.sysRoleService.update(sysRole));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @ApiOperation(value = "通过主键查询角色数据")
    @GetMapping("/selectById/{id}")
    public Result selectById(@PathVariable("id") Long id) {
        if (id == null) {
            return Result.failure("用户id不能为空");
        }
        return Result.success(this.sysRoleService.selectById(id));
    }

    /**
     * 分页查询
     *
     * @param sysRole 筛选条件
     * @return 查询结果
     */
    @ApiOperation(value = "分页查询角色数据")
    @GetMapping("/selectByPage")
    public Result selectByPage(SysRole sysRole, PageVo pageVo) {
        PageHelper.startPage(pageVo.getPage(), pageVo.getLimit());
        List<SysRole> sysRoles = this.sysRoleService.selectByPage(sysRole);
        return Result.success(new PageInfo(sysRoles));
    }


}

