package com.coob.sjts.modules.system.controller;

import com.coob.sjts.common.web.PageVo;
import com.coob.sjts.common.web.Result;
import com.coob.sjts.modules.system.domain.SysUser;
import com.coob.sjts.modules.system.service.SysUserService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * (SysUser)表控制层
 *
 * @author wangqingli
 * @since 2024-05-30 14:11:56
 */
@Api(tags = "用户菜单")
@RestController
@RequestMapping("sys/user")
public class SysUserController {
    /**
     * 服务对象
     */
    @Resource
    private SysUserService sysUserService;


    /**
     * 新增数据
     *
     * @param sysUser 实体
     * @return 新增结果
     */
    @PostMapping("/add")
    public Result add(@RequestBody SysUser sysUser) {
        String msg = sysUser.checkAddParams();
        if (StringUtils.isNotBlank(msg)) {
            return Result.failure(msg);
        }
        sysUser.setState(1);
        //把输入密码进行加密 MD5
//        String encrypt = MD5.encrypt(sysUser.getPassword());
//        sysUser.setPassword(encrypt);

        boolean is_Success = this.sysUserService.insert(sysUser);
        if (is_Success) {
            return Result.success();
        } else {
            return Result.failure();
        }
    }


    /**
     * 删除数据
     *
     * @param id 主键
     * @return 删除是否成功
     */
    @ApiOperation(value = "删除用户数据")
    @GetMapping("/deleteById/{id}")
    public Result deleteById(@PathVariable Integer id) {
        if (id == null) {
            return Result.failure("id不能为空");
        }
        return Result.success(this.sysUserService.deleteById(id));
    }

    /**
     * 编辑数据
     *
     * @param sysUser 实体
     * @return 编辑结果
     */
    @ApiOperation(value = "编辑用户数据")
    @PostMapping("/edit")
    public Result edit(@RequestBody SysUser sysUser) {
        String msg = sysUser.checkEditParams();
        if (StringUtils.isNotBlank(msg)) {
            return Result.failure(msg);
        }
        boolean update = this.sysUserService.update(sysUser);
        if (update) {
            return Result.success();
        }
        return Result.failure();
    }


    @ApiOperation("更改用户状态")
    @GetMapping("updateStatus/{id}/{state}")
    public Result updateStatus(@PathVariable Integer id,
                               @PathVariable Integer state) {
        if (id == null) {
            return Result.failure("id不能为空");
        }
        if (state == null) {
            return Result.failure("状态不能为空");
        }
        boolean update = sysUserService.updateStatus(id, state);
        if (update) {
            return Result.success();
        }
        return Result.failure("状态修改失败");
    }

    /**
     * 分页查询
     *
     * @param sysUser 筛选条件
     * @return 查询结果
     */
    @ApiOperation(value = "分页查询用户数据")
    @GetMapping("/selectByPage")
    public Result selectByPage(SysUser sysUser, PageVo pageVo) {
        PageHelper.startPage(pageVo.getPage(), pageVo.getLimit());
        List<SysUser> sysUsers = this.sysUserService.selectByPage(sysUser);
        return Result.success(new PageInfo(sysUsers));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @ApiOperation(value = "通过主键查询用户数据")
    @GetMapping("/selectById/{id}")
    public Result selectById(@PathVariable("id") Integer id) {
        if (id == null) {
            return Result.failure("id不能为空");
        }
        return Result.success(this.sysUserService.selectById(id));
    }

}

