package com.coob.sjts.modules.system.mapper;

import com.coob.sjts.datasource.constant.DBConstants;
import com.coob.sjts.modules.system.domain.SysUser;
import org.apache.ibatis.annotations.Mapper;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * (SysUser)表数据库访问层
 *
 * @author wangqingli
 * @since 2024-05-30 14:11:56
 */
@Mapper
@Transactional(transactionManager = DBConstants.TX_MANAGER_SYS)
public interface SysUserMapper {


    /**
     * 新增数据
     *
     * @param sysUser 实例对象
     * @return 影响行数
     */
    boolean insert(SysUser sysUser);

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 影响行数
     */
    boolean deleteById(Integer id);

    /**
     * 修改数据
     *
     * @param sysUser 实例对象
     * @return 影响行数
     */
    boolean update(SysUser sysUser);



    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    SysUser selectById(Integer id);


    /**
     * 根据账号查询用户
     *
     * @param account
     * @return
     */
    SysUser selectByAccount(String account);

    /**
     * 查询指定行数据
     *
     * @param sysUser 查询条件
     * @return 对象列表
     */
    List<SysUser> selectList(SysUser sysUser);

}

